@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -25,9 +26,6 @@
  *
  ************************************************************************/
 
-#ifdef PCH
-#endif
-
 #ifdef _MSC_VER
 #pragma hdrstop
 #endif
@@ -38,6 +36,7 @@
 #include <bf_svtools/zforlist.hxx>
 #include <string.h>
 #include <math.h>
+#include <sal/macros.h>
 
 #include "interpre.hxx"
 #include "bf_sc.hrc"
@@ -47,6 +46,7 @@
 #include "unitconv.hxx"
 #include "globstr.hrc"
 #include "hints.hxx"
+
 namespace binfilter {
 
 // STATIC DATA -----------------------------------------------------------
@@ -2026,7 +2026,7 @@ void ScInterpreter::ScRoman()
         {
             static const sal_Unicode pChars[] = { 'M', 'D', 'C', 'L', 'X', 'V', 'I' };
             static const USHORT pValues[] = { 1000, 500, 100, 50, 10, 5, 1 };
-            static const USHORT nMaxIndex = (USHORT)(sizeof(pValues) / sizeof(pValues[0]) - 1);
+            static const USHORT nMaxIndex = (USHORT)(SAL_N_ELEMENTS(pValues) - 1);
 
             String aRoman;
             USHORT nVal = (USHORT) fVal;
@@ -2145,3 +2145,5 @@ void ScInterpreter::ScArabic()
 
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
