@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -25,15 +26,10 @@
  *
  ************************************************************************/
 
-#ifdef PCH
-#endif
-
 #ifdef _MSC_VER
 #pragma hdrstop
 #endif
 
-// INCLUDE ---------------------------------------------------------------
-
 #include "scitems.hxx"
 #define ITEMID_FIELD EE_FEATURE_FIELD
 
@@ -47,12 +43,8 @@
 #include <bf_svx/sizeitem.hxx>
 #include <bf_svx/ulspitem.hxx>
 #include <bf_sfx2/printer.hxx>
-#ifndef _SFXDOCFILE_HXX //autogen
 #include <bf_sfx2/docfile.hxx>
-#endif
-#ifndef _URLOBJ_HXX //autogen
 #include <tools/urlobj.hxx>
-#endif
 
 #ifdef MAC
 #define RGBColor MAC_RGBColor
@@ -60,12 +52,6 @@
 #else
 #endif
 
-
-//#if defined( WIN ) || defined( WNT )
-//#include <svwin.h>
-//#endif
-
-
 #include "docsh.hxx"
 #include "stlpool.hxx"
 #include "attrib.hxx"
@@ -1077,3 +1063,5 @@ namespace binfilter {
 /*N*/ }
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
