@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -25,9 +26,7 @@
  *
  ************************************************************************/
 
-#ifndef _SOLAR_H
 #include <Solar.h>
-#endif
 
 #if defined (MAC)
 #include <mac_start.h>
@@ -51,9 +50,7 @@
 #include <mac_end.h>
 #endif
 
-#ifndef _SV_HXX
 #include <sv.hxx>
-#endif
 
 #include "xpoly.hxx"
 #include "xattr.hxx"
@@ -1681,3 +1678,5 @@ long XOutputDevice::DrawFormText(const String& rText, const XPolygon& rXPoly,
 }
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
