@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -33,30 +34,18 @@
 #include "errhdl.hxx"
 #include "paratr.hxx"
 
-#ifndef _HORIORNT_HXX
 #include <horiornt.hxx>
-#endif
 
 
-#ifndef _SVX_ADJITEM_HXX //autogen
 #include <bf_svx/adjitem.hxx>
-#endif
-#ifndef _SVX_LSPCITEM_HXX //autogen
 #include <bf_svx/lspcitem.hxx>
-#endif
-#ifndef _SVX_LRSPITEM_HXX //autogen
 #include <bf_svx/lrspitem.hxx>
-#endif
 
-#ifndef _FRMATR_HXX
 #include <frmatr.hxx>
-#endif
 
 #ifdef VERTICAL_LAYOUT
-#ifndef _PAGEDESC_HXX
 #include <pagedesc.hxx> // SwPageDesc
 #endif
-#endif
 
 #include "txtcfg.hxx"
 #include "itrtxt.hxx"
@@ -65,9 +54,7 @@
 #include "porfly.hxx"		// GetFlyCrsrOfst()
 #include "pordrop.hxx"
 #include "crstate.hxx"      // SwCrsrMoveState
-#ifndef _PORMULTI_HXX
 #include <pormulti.hxx> 	// SwMultiPortion
-#endif
 namespace binfilter {
 
 extern BYTE WhichFont( xub_StrLen nIdx, const String* pTxt,
@@ -1133,3 +1120,5 @@ sal_Bool SwTxtCursor::bRightMargin = sal_False;
 /*N*/ }
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
