@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -403,7 +404,7 @@ static EnhancedCustomShapeParameter GetAdjCoordinate( CustomShapeProperties& rCu
             }
             if ( ( n >= '0' ) && ( n <= '9' ) )
             {	// seems to be a ST_Coordinate
-                aRet.Value = Any( rValue.toInt32() );
+                aRet.Value = Any( (sal_Int32)(rValue.toInt32() / 5) );
                 aRet.Type = EnhancedCustomShapeParameterType::NORMAL;
             }
             else
@@ -2066,3 +2067,5 @@ Reference< XFastContextHandler > PresetTextShapeContext::createFastChildContext(
 }
 
 } }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
